@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ticktick" "1.0.1"
+(define-package "ticktick" "20251119.45"
   "Sync Org Mode tasks with TickTick."
   '((emacs        "27.1")
     (request      "0.3.0")
     (simple-httpd "1.5.0"))
   :url "https://github.com/polhuang/ticktick.el"
-  :commit "83692995ff14cf61b97ec7f68693c214c56b566b"
-  :revdesc "v1.0.1-0-g83692995ff14"
+  :commit "860de3af35da55f0e0866b4589dbf1fa877501f0"
+  :revdesc "860de3af35da"
   :keywords '("tools" "ticktick" "org" "tasks" "todo"))
